Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'release/scripts/op/uv.py')
-rw-r--r--release/scripts/op/uv.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/release/scripts/op/uv.py b/release/scripts/op/uv.py
index 51c1695677b..a7abd475b8d 100644
--- a/release/scripts/op/uv.py
+++ b/release/scripts/op/uv.py
@@ -85,9 +85,9 @@ class ExportUVLayout(bpy.types.Operator):
for i in range(uv_layer_len):
uv_elem = uv_layer[i]
# context checks
- if faces[i].selected and (local_image is Ellipsis or local_image == uv_elem.image):
+ if faces[i].select and (local_image is Ellipsis or local_image == uv_elem.image):
#~ uv = uv_elem.uv
#~ if False not in uv_elem.uv_selected[:len(uv)]:
#~ yield (i, uv)
# just write what we see.
@@ -85,9 +85,9 @@ class ExportUVLayout(bpy.types.Operator):
#~ uv = uv_elem.uv
- #~ if False not in uv_elem.uv_selected[:len(uv)]:
+ #~ if False not in uv_elem.select_uv[:len(uv)]:
#~ yield (i, uv)
# just write what we see.